Function try_combine_lo_hi_u64

pub fn try_combine_lo_hi_u64(
    amount_lo: u64,
    amount_hi: u64,
    bit_length: usize,
) -> Option<u64>
👎Deprecated since 0.6.0: This function is deprecated as it contains logical errors and is unused in the crate
Combine two numbers that are interpreted as the low and high bits of a target number. The bit_length parameter specifies the number of bits that amount_hi is to be shifted by.